==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/barrel/dialogs_bg.lua <==
dialogId("bar-v-videt0", "font_big", "Somebody from Greenpeace should see this.")
dialogStr("Някой от Грийнпийс трябва да види това.")

dialogId("bar-m-videt1", "font_small", "Somebody from Three Miles Island should see this.")
dialogStr("Някой от петкилометровия остров трябва да види това.")

dialogId("bar-v-co", "font_big", "What are we supposed to do with it?")
dialogStr("Какво се предполага, че трябва да правим с това?")

dialogId("bar-m-pobit", "font_small", "We have to exterminate all of them. Such abominations have no right to breath the same air... er, water, as we do.")
dialogStr("Трябва да ги избием всичките. Подобни изроди нямат право да дишат съшия въздух... ъ, вода... като нас.")

dialogId("bar-v-priciny", "font_big", "I think we have to eliminate the cause and not the results.")
dialogStr("Аз мисля, че трябва да отстраним причината, а не следствията.")

dialogId("bar-m-no", "font_small", "Well, you may be right.")
dialogStr("Е, може би си прав.")

dialogId("bar-v-sud", "font_big", "And the cause is doubtless this giant barrel. We have to get it out somehow.")
dialogStr("А причината без съмнение е този голям варел. Трябва някак да го разкараме.")

dialogId("bar-m-panb", "font_small", "Yes. Let’s get to work. We can drop it on the Mr. B.’s front yard afterwards.")
dialogStr("Да. Да се залавяме за работа. След това може да го хвърлим в предния двор ма г-н Ш.")

dialogId("bar-m-rada", "font_small", "I think I am growing to like them.")
dialogStr("Май започвам да ги харесвам.")

dialogId("bar-v-kdyby0", "font_big", "If only they wouldn’t stand in our way so much.")
dialogStr("Само ако не ни пречеха толкова...")

dialogId("bar-v-kdyby1", "font_big", "If only they were where we need them.")
dialogStr("Ако и бяха където трябва...")

dialogId("bar-v-sbirka", "font_big", "Such a lovely collection of monstrosities. I’ll be sorry to leave.")
dialogStr("Каква прекрасна сбирка от уроди. Направо не ми се тръгва")

dialogId("bar-m-dost0", "font_small", "That won’t happen any time soon.")
dialogStr("И без това скоро няма да си ходим.")

dialogId("bar-m-dost1", "font_small", "You are going to have plenty of time to enjoy them.")
dialogStr("Ще имаш достатъчно време за да им се радваш.")

dialogId("bar-v-lih", "font_big", "If we take them with us and store them in alcohol, we could found ourselves a freak show.")
dialogStr("Ако ги вземем с нас консервирани в спирт можем да основем някое откачено шоу.")

dialogId("bar-m-fdto", "font_small", "And FDTO isn’t enough for you?")
dialogStr("ГЛШ не ти ли стига?")

dialogId("bar-x-vypr", "font_white", "I can hear everything!")
dialogStr("Чувам всичко!")

dialogId("bar-m-promin", "font_small", "Sorry, boss. I didn’t mean to offend.")
dialogStr("Съжалявам, шефе. Не исках да те обидя.")

dialogId("bar-m-mutanti", "font_small", "You know, I finally realized that even mutants have a soul.")
dialogStr("Знаеш ли, изведнъж осъзнах, че дори и мутантите имат душа.")

dialogId("bar-v-ufouni", "font_big", "Maybe even UFOs can have a soul.")
dialogStr("Може би дори и НЛО-тата могат да имат душа.")

dialogId("bar-m-zmeni", "font_small", "I think that this level is going to change us forever.")
dialogStr("Мисля, че това ниво ще ни промени завинаги.")

dialogId("bar-m-noha", "font_small", "That foot is not only repulsive but also shameless. Just look at it.")
dialogStr("Този крак не е просто отблъскващ, а и безсрамен. Погледни го само.")

dialogId("bar-v-pld", "font_big", "Look at that pld. It looks the same and still it grows more and more repulsive.")
dialogStr("Погледни го. Изглежда все така и все пак става все по-отвратително.")

dialogId("bar-m-pudy", "font_small", "But even it harbors some motherly instincts. Look how it cares about the little one.")
dialogStr("Но все пак таи майчински инстинкти. Погледни как се грижи за малкото.")

dialogId("bar-v-traverza", "font_big", "Yes. It almost killed it with iron beam.")
dialogStr("Да. Почти го уби с железния лъч.")

dialogId("bar-m-rybka", "font_small", "This fish looks familiar to me.")
dialogStr("Тази риба ми изглежда позната.")

dialogId("bar-v-fotka", "font_big", "Maybe it was in that photo from the power plant.")
dialogStr("Може би тя е била на снимката при реактора.")

dialogId("bar-v-krab", "font_big", "The poor crab. So many pincers and no head. Although... maybe he is better off than us.")
dialogStr("Бедния рак. Толкова щипци, а няма глава. Макар, че... май си е по-добре от нас.")

dialogId("bar-m-kachna", "font_small", "No man is alone with a little yellow duck. Not even fish.")
dialogStr("Човек не може да е самотен ако има малко жълто пате. Същото е и с рибите.")

dialogId("bar-m-barel", "font_small", "This time, our goal is to push out the barrel with that filth.")
dialogStr("Този път целта ни е да избутаме варела с тази гряз.")

dialogId("bar-v-genofond", "font_big", "But we have to leave all those creatures here. They must not harm the genepool of the healthy population.")
dialogStr("Обаче трябва да оставим всички създания тук. Не трябва да се замърсяват генния фонд на здравата популация.")

dialogId("bar-x-kchkch", "", "")
dialogStr("")

dialogId("bar-x-gr0", "", "")
dialogStr("")

dialogId("bar-x-gr1", "", "")
dialogStr("")

dialogId("bar-x-gr2", "", "")
dialogStr("")

dialogId("bar-x-tup", "", "")
dialogStr("")

dialogId("bar-x-zzz", "", "")
dialogStr("")

dialogId("bar-x-suck0", "", "")
dialogStr("")

dialogId("bar-x-suck1", "", "")
dialogStr("")

dialogId("bar-x-suck2", "", "")
dialogStr("")

dialogId("bar-x-suck3", "", "")
dialogStr("")

dialogId("bar-x-suckano", "", "")
dialogStr("")

dialogId("bar-x-suckne", "", "")
dialogStr("")

==> fillets-ng-data_1.0.1.orig.tar.gz: fillets-ng-data-1.0.1/script/barrel/dialogs_bg.lua <==
dialogId("bar-v-videt0", "font_big", "Somebody from Greenpeace should see this.")
dialogStr("Някой от Грийнпийс трябва да види това.")

dialogId("bar-m-videt1", "font_small", "Somebody from Three Mile Island should see this.")
dialogStr("Някой от петкилометровия остров трябва да види това.")

dialogId("bar-v-co", "font_big", "What are we supposed to do with it?")
dialogStr("Какво се предполага, че трябва да правим с това?")

dialogId("bar-m-pobit", "font_small", "We have to exterminate all of them. Such abominations have no right to breath the same air... er, water, as we do.")
dialogStr("Трябва да ги избием всичките. Подобни изроди нямат право да дишат съшия въздух... ъ, вода... като нас.")

dialogId("bar-v-priciny", "font_big", "I think we have to eliminate the cause and not the results.")
dialogStr("Аз мисля, че трябва да отстраним причината, а не следствията.")

dialogId("bar-m-no", "font_small", "Well, you may be right.")
dialogStr("Е, може би си прав.")

dialogId("bar-v-sud", "font_big", "And the cause is doubtless this giant barrel. We have to get it out somehow.")
dialogStr("А причината без съмнение е този голям варел. Трябва някак да го разкараме.")

dialogId("bar-m-panb", "font_small", "Yes. Let’s get to work. We can drop it on the Mr. B.’s front yard afterwards.")
dialogStr("Да. Да се залавяме за работа. След това може да го хвърлим в предния двор ма г-н Ш.")

dialogId("bar-m-rada", "font_small", "I think I am growing to like them.")
dialogStr("Май започвам да ги харесвам.")

dialogId("bar-v-kdyby0", "font_big", "If only they wouldn’t stand in our way so much.")
dialogStr("Само ако не ни пречеха толкова...")

dialogId("bar-v-kdyby1", "font_big", "If only they were where we need them.")
dialogStr("Ако и бяха където трябва...")

dialogId("bar-v-sbirka", "font_big", "Such a lovely collection of monstrosities. I’ll be sorry to leave.")
dialogStr("Каква прекрасна сбирка от уроди. Направо не ми се тръгва")

dialogId("bar-m-dost0", "font_small", "That won’t happen any time soon.")
dialogStr("И без това скоро няма да си ходим.")

dialogId("bar-m-dost1", "font_small", "You are going to have plenty of time to enjoy them.")
dialogStr("Ще имаш достатъчно време за да им се радваш.")

dialogId("bar-v-lih", "font_big", "If we take them with us and store them in alcohol, we could found ourselves a freak show.")
dialogStr("Ако ги вземем с нас консервирани в спирт можем да основем някое откачено шоу.")

dialogId("bar-m-fdto", "font_small", "And FDTO isn’t enough for you?")
dialogStr("ГЛШ не ти ли стига?")

dialogId("bar-x-vypr", "font_white", "I can hear everything!")
dialogStr("Чувам всичко!")

dialogId("bar-m-promin", "font_small", "Sorry, boss. I didn’t mean to offend.")
dialogStr("Съжалявам, шефе. Не исках да те обидя.")

dialogId("bar-m-mutanti", "font_small", "You know, I finally realized that even mutants have a soul.")
dialogStr("Знаеш ли, изведнъж осъзнах, че дори и мутантите имат душа.")

dialogId("bar-v-ufouni", "font_big", "Maybe even UFOs can have a soul.")
dialogStr("Може би дори и НЛО-тата могат да имат душа.")

dialogId("bar-m-zmeni", "font_small", "I think that this level is going to change us forever.")
dialogStr("Мисля, че това ниво ще ни промени завинаги.")

dialogId("bar-m-noha", "font_small", "That foot is not only repulsive but also shameless. Just look at it.")
dialogStr("Този крак не е просто отблъскващ, а и безсрамен. Погледни го само.")

dialogId("bar-v-pld", "font_big", "Look at that pld. It looks the same and still it grows more and more repulsive.")
dialogStr("Погледни го. Изглежда все така и все пак става все по-отвратително.")

dialogId("bar-m-pudy", "font_small", "But even it harbors some motherly instincts. Look how it cares about the little one.")
dialogStr("Но все пак таи майчински инстинкти. Погледни как се грижи за малкото.")

dialogId("bar-v-traverza", "font_big", "Yes. It almost killed it with iron beam.")
dialogStr("Да. Почти го уби с железния лъч.")

dialogId("bar-m-rybka", "font_small", "This fish looks familiar to me.")
dialogStr("Тази риба ми изглежда позната.")

dialogId("bar-v-fotka", "font_big", "Maybe it was in that photo from the power plant.")
dialogStr("Може би тя е била на снимката при реактора.")

dialogId("bar-v-krab", "font_big", "The poor crab. So many pincers and no head. Although... maybe he is better off than us.")
dialogStr("Бедния рак. Толкова щипци, а няма глава. Макар, че... май си е по-добре от нас.")

dialogId("bar-m-kachna", "font_small", "No man is alone with a little yellow duck. Not even fish.")
dialogStr("Човек не може да е самотен ако има малко жълто пате. Същото е и с рибите.")

dialogId("bar-m-barel", "font_small", "This time, our goal is to push out the barrel with that filth.")
dialogStr("Този път целта ни е да избутаме варела с тази гряз.")

dialogId("bar-v-genofond", "font_big", "But we have to leave all those creatures here. They must not harm the genepool of the healthy population.")
dialogStr("Обаче трябва да оставим всички създания тук. Не трябва да се замърсяват генния фонд на здравата популация.")

dialogId("bar-x-kchkch", "", "")
dialogStr("")

dialogId("bar-x-gr0", "", "")
dialogStr("")

dialogId("bar-x-gr1", "", "")
dialogStr("")

dialogId("bar-x-gr2", "", "")
dialogStr("")

dialogId("bar-x-tup", "", "")
dialogStr("")

dialogId("bar-x-zzz", "", "")
dialogStr("")

dialogId("bar-x-suck0", "", "")
dialogStr("")

dialogId("bar-x-suck1", "", "")
dialogStr("")

dialogId("bar-x-suck2", "", "")
dialogStr("")

dialogId("bar-x-suck3", "", "")
dialogStr("")

dialogId("bar-x-suckano", "", "")
dialogStr("")

dialogId("bar-x-suckne", "", "")
dialogStr("")
